function out=teqcfv(files)

% TEQCFV Read and plot TEQC report files (fast view)
%
%   TEQC is the Toolkit for GPS/GLONASS/SBAS Data used to solve 
%   many pre-processing problems with GPS, GLONASS, and SBAS data:
%   TEQC stands for Translation, Editing, and Quality Check
%   More info here: http://facility.unavco.org/software/teqc/teqc.html
%
%   TEQCFV(FILENAME) returns the content of a TEQC reportfile in
%   a figure (and a matrix).
%   Input argument FILENAME is optional. 
%
%   Valid TEQC report files are:
%  
%   FORMAT  DESCRIPTION
%   *.sn1   Signal to noise ratio (S/N) Carrier L1
%   *.sn2   Signal to noise ratio (S/N) Carrier L2
%   *.iod   Derivative of ionospheric delay observable (m/s)
%   *.ion   Ionospheric delay observable (m)
%   *.mp1   Multipath Carrier L1
%   *.mp2   Multipath Carrier L2
%   *.azi   Satellite azimuthal data (degrees)
%   *.ele   Satellite elevation data (degrees)
%
%   LWINKLER, 2010
%   
%   winklerl@mnstate.edu

% FUNCTION: READER & PLOTTER ++++++++++++++++++++++++++++++++++++++++++++++
if nargin==0
    [filen,path]=uigetfile('*.sn1;*.sn2;*.iod;*.ion;*.mp1;*.mp2;*.azi;*.ele',...
        'Pick your TEQC report file');
else
    [path,filen,ext]=fileparts(files);
    path=[path '\'];
    filen={[filen ext]};
end
file=char(filen);
fid=fopen(file);
i=1;
        while 1
            tline = fgetl(fid);
            if ~ischar(tline), break, end
            nl{i}=tline;
            i=i+1;
        end;
        fclose(fid);
        Newdat=strcmp('-1',nl);
        for j=1:length(nl);
            Olddat(j)=1;
            lineit=nl{j};
            udat=findstr('.',lineit);
            if isempty(udat)
                Olddat(j)=0;
            end;
        end;
        Olddat(1:4)=1;
        Satd=~(Newdat | Olddat);
        sind=find(Satd == 1);
        nd=0;
        vdat(:,1:32)=0;
        time(:,1:32)=0;
        for k=1:(length(sind)-1);
            satel=sscanf(nl{sind(k)},'%u');
            for kk=sind(k):sind(k+1);
                if Olddat(kk)==1
                    sdat=sscanf(nl{kk},'%f');
                    nd=nd+1;
                  for kkk=1:length(sdat);  
                      vdat(satel(kkk+1),nd)=sdat(kkk);
                  end;
                end;
            end;
        end;
        cmax=max(max(vdat));
        cmin=min(min(vdat));
        clim=[cmin cmax];
        imagesc(vdat, clim);
        colorbar;
        hold on;
        xlabel(' Time in intervals since begin time');
        set(gca,'YTick',1:32);
        ylabel(' Satellite number');
        impdat=[nl{3} '   ' nl{4}];
        title(impdat);
        out=vdat;
        
        
                